==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/LongTermRetentionPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.LongTermRetentionPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Long term retention policy.
 * @property dailySchedule Daily retention schedule of the protection policy.
 * @property monthlySchedule Monthly retention schedule of the protection policy.
 * @property retentionPolicyType This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
 * Expected value is 'LongTermRetentionPolicy'.
 * @property weeklySchedule Weekly retention schedule of the protection policy.
 * @property yearlySchedule Yearly retention schedule of the protection policy.
 */
public data class LongTermRetentionPolicyArgs(
    public val dailySchedule: Output<DailyRetentionScheduleArgs>? = null,
    public val monthlySchedule: Output<MonthlyRetentionScheduleArgs>? = null,
    public val retentionPolicyType: Output<String>,
    public val weeklySchedule: Output<WeeklyRetentionScheduleArgs>? = null,
    public val yearlySchedule: Output<YearlyRetentionScheduleArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.LongTermRetentionPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.LongTermRetentionPolicyArgs =
        com.pulumi.azurenative.recoveryservices.inputs.LongTermRetentionPolicyArgs.builder()
            .dailySchedule(dailySchedule?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .monthlySchedule(monthlySchedule?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retentionPolicyType(retentionPolicyType.applyValue({ args0 -> args0 }))
            .weeklySchedule(weeklySchedule?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .yearlySchedule(
                yearlySchedule?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [LongTermRetentionPolicyArgs].
 */
@PulumiTagMarker
public class LongTermRetentionPolicyArgsBuilder internal constructor() {
    private var dailySchedule: Output<DailyRetentionScheduleArgs>? = null

    private var monthlySchedule: Output<MonthlyRetentionScheduleArgs>? = null

    private var retentionPolicyType: Output<String>? = null

    private var weeklySchedule: Output<WeeklyRetentionScheduleArgs>? = null

    private var yearlySchedule: Output<YearlyRetentionScheduleArgs>? = null

    /**
     * @param value Daily retention schedule of the protection policy.
     */
    @JvmName("hklevlheleldecjv")
    public suspend fun dailySchedule(`value`: Output<DailyRetentionScheduleArgs>) {
        this.dailySchedule = value
    }

    /**
     * @param value Monthly retention schedule of the protection policy.
     */
    @JvmName("mufmghmbkicatmav")
    public suspend fun monthlySchedule(`value`: Output<MonthlyRetentionScheduleArgs>) {
        this.monthlySchedule = value
    }

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'LongTermRetentionPolicy'.
     */
    @JvmName("pjaluvprvvqbrvuy")
    public suspend fun retentionPolicyType(`value`: Output<String>) {
        this.retentionPolicyType = value
    }

    /**
     * @param value Weekly retention schedule of the protection policy.
     */
    @JvmName("gaknbmqbioxbssve")
    public suspend fun weeklySchedule(`value`: Output<WeeklyRetentionScheduleArgs>) {
        this.weeklySchedule = value
    }

    /**
     * @param value Yearly retention schedule of the protection policy.
     */
    @JvmName("kfryuytqqkpsaejo")
    public suspend fun yearlySchedule(`value`: Output<YearlyRetentionScheduleArgs>) {
        this.yearlySchedule = value
    }

    /**
     * @param value Daily retention schedule of the protection policy.
     */
    @JvmName("prhcnsnlahkbafme")
    public suspend fun dailySchedule(`value`: DailyRetentionScheduleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dailySchedule = mapped
    }

    /**
     * @param argument Daily retention schedule of the protection policy.
     */
    @JvmName("ojdosdjukstuqslp")
    public suspend fun dailySchedule(argument: suspend DailyRetentionScheduleArgsBuilder.() -> Unit) {
        val toBeMapped = DailyRetentionScheduleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.dailySchedule = mapped
    }

    /**
     * @param value Monthly retention schedule of the protection policy.
     */
    @JvmName("qpsgxapfveksvnjw")
    public suspend fun monthlySchedule(`value`: MonthlyRetentionScheduleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthlySchedule = mapped
    }

    /**
     * @param argument Monthly retention schedule of the protection policy.
     */
    @JvmName("scewemenvjuydntq")
    public suspend
    fun monthlySchedule(argument: suspend MonthlyRetentionScheduleArgsBuilder.() -> Unit) {
        val toBeMapped = MonthlyRetentionScheduleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.monthlySchedule = mapped
    }

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'LongTermRetentionPolicy'.
     */
    @JvmName("byqeyicdoyxmmafq")
    public suspend fun retentionPolicyType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionPolicyType = mapped
    }

    /**
     * @param value Weekly retention schedule of the protection policy.
     */
    @JvmName("htfwlrxqcapfuvea")
    public suspend fun weeklySchedule(`value`: WeeklyRetentionScheduleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weeklySchedule = mapped
    }

    /**
     * @param argument Weekly retention schedule of the protection policy.
     */
    @JvmName("smaqkrsycfwvxbkw")
    public suspend
    fun weeklySchedule(argument: suspend WeeklyRetentionScheduleArgsBuilder.() -> Unit) {
        val toBeMapped = WeeklyRetentionScheduleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.weeklySchedule = mapped
    }

    /**
     * @param value Yearly retention schedule of the protection policy.
     */
    @JvmName("bkojrhqwsokqefgn")
    public suspend fun yearlySchedule(`value`: YearlyRetentionScheduleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.yearlySchedule = mapped
    }

    /**
     * @param argument Yearly retention schedule of the protection policy.
     */
    @JvmName("hfndodlcbsfrettt")
    public suspend
    fun yearlySchedule(argument: suspend YearlyRetentionScheduleArgsBuilder.() -> Unit) {
        val toBeMapped = YearlyRetentionScheduleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.yearlySchedule = mapped
    }

    internal fun build(): LongTermRetentionPolicyArgs = LongTermRetentionPolicyArgs(
        dailySchedule = dailySchedule,
        monthlySchedule = monthlySchedule,
        retentionPolicyType = retentionPolicyType ?: throw PulumiNullFieldException("retentionPolicyType"),
        weeklySchedule = weeklySchedule,
        yearlySchedule = yearlySchedule,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/LongTermRetentionPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.LongTermRetentionPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Long term retention policy.
 * @property dailySchedule Daily retention schedule of the protection policy.
 * @property monthlySchedule Monthly retention schedule of the protection policy.
 * @property retentionPolicyType This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
 * Expected value is 'LongTermRetentionPolicy'.
 * @property weeklySchedule Weekly retention schedule of the protection policy.
 * @property yearlySchedule Yearly retention schedule of the protection policy.
 */
public data class LongTermRetentionPolicyArgs(
    public val dailySchedule: Output<DailyRetentionScheduleArgs>? = null,
    public val monthlySchedule: Output<MonthlyRetentionScheduleArgs>? = null,
    public val retentionPolicyType: Output<String>,
    public val weeklySchedule: Output<WeeklyRetentionScheduleArgs>? = null,
    public val yearlySchedule: Output<YearlyRetentionScheduleArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.LongTermRetentionPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.LongTermRetentionPolicyArgs =
        com.pulumi.azurenative.recoveryservices.inputs.LongTermRetentionPolicyArgs.builder()
            .dailySchedule(dailySchedule?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .monthlySchedule(monthlySchedule?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retentionPolicyType(retentionPolicyType.applyValue({ args0 -> args0 }))
            .weeklySchedule(weeklySchedule?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .yearlySchedule(
                yearlySchedule?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [LongTermRetentionPolicyArgs].
 */
@PulumiTagMarker
public class LongTermRetentionPolicyArgsBuilder internal constructor() {
    private var dailySchedule: Output<DailyRetentionScheduleArgs>? = null

    private var monthlySchedule: Output<MonthlyRetentionScheduleArgs>? = null

    private var retentionPolicyType: Output<String>? = null

    private var weeklySchedule: Output<WeeklyRetentionScheduleArgs>? = null

    private var yearlySchedule: Output<YearlyRetentionScheduleArgs>? = null

    /**
     * @param value Daily retention schedule of the protection policy.
     */
    @JvmName("roevefegrrudnsdc")
    public suspend fun dailySchedule(`value`: Output<DailyRetentionScheduleArgs>) {
        this.dailySchedule = value
    }

    /**
     * @param value Monthly retention schedule of the protection policy.
     */
    @JvmName("mlxjacdsbecuuqsm")
    public suspend fun monthlySchedule(`value`: Output<MonthlyRetentionScheduleArgs>) {
        this.monthlySchedule = value
    }

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'LongTermRetentionPolicy'.
     */
    @JvmName("kubatgiwupdqwafy")
    public suspend fun retentionPolicyType(`value`: Output<String>) {
        this.retentionPolicyType = value
    }

    /**
     * @param value Weekly retention schedule of the protection policy.
     */
    @JvmName("iidjfvssmqkxdvtu")
    public suspend fun weeklySchedule(`value`: Output<WeeklyRetentionScheduleArgs>) {
        this.weeklySchedule = value
    }

    /**
     * @param value Yearly retention schedule of the protection policy.
     */
    @JvmName("croodmpgsqfaityd")
    public suspend fun yearlySchedule(`value`: Output<YearlyRetentionScheduleArgs>) {
        this.yearlySchedule = value
    }

    /**
     * @param value Daily retention schedule of the protection policy.
     */
    @JvmName("qyvqbinxkbvgtqoe")
    public suspend fun dailySchedule(`value`: DailyRetentionScheduleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dailySchedule = mapped
    }

    /**
     * @param argument Daily retention schedule of the protection policy.
     */
    @JvmName("yncavniqmfmjacen")
    public suspend fun dailySchedule(argument: suspend DailyRetentionScheduleArgsBuilder.() -> Unit) {
        val toBeMapped = DailyRetentionScheduleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.dailySchedule = mapped
    }

    /**
     * @param value Monthly retention schedule of the protection policy.
     */
    @JvmName("iuxbpfwsbhcnmuvy")
    public suspend fun monthlySchedule(`value`: MonthlyRetentionScheduleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthlySchedule = mapped
    }

    /**
     * @param argument Monthly retention schedule of the protection policy.
     */
    @JvmName("bbauxsejkyeqwahv")
    public suspend
    fun monthlySchedule(argument: suspend MonthlyRetentionScheduleArgsBuilder.() -> Unit) {
        val toBeMapped = MonthlyRetentionScheduleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.monthlySchedule = mapped
    }

    /**
     * @param value This property will be used as the discriminator for deciding the specific types in the polymorphic chain of types.
     * Expected value is 'LongTermRetentionPolicy'.
     */
    @JvmName("bsvruaqujwhhgtyi")
    public suspend fun retentionPolicyType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionPolicyType = mapped
    }

    /**
     * @param value Weekly retention schedule of the protection policy.
     */
    @JvmName("hgblwuxmaxaoqxad")
    public suspend fun weeklySchedule(`value`: WeeklyRetentionScheduleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weeklySchedule = mapped
    }

    /**
     * @param argument Weekly retention schedule of the protection policy.
     */
    @JvmName("huvhtlrvxspugggb")
    public suspend
    fun weeklySchedule(argument: suspend WeeklyRetentionScheduleArgsBuilder.() -> Unit) {
        val toBeMapped = WeeklyRetentionScheduleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.weeklySchedule = mapped
    }

    /**
     * @param value Yearly retention schedule of the protection policy.
     */
    @JvmName("dwjcxuqofmvswywl")
    public suspend fun yearlySchedule(`value`: YearlyRetentionScheduleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.yearlySchedule = mapped
    }

    /**
     * @param argument Yearly retention schedule of the protection policy.
     */
    @JvmName("jrhlvvsphmymakiq")
    public suspend
    fun yearlySchedule(argument: suspend YearlyRetentionScheduleArgsBuilder.() -> Unit) {
        val toBeMapped = YearlyRetentionScheduleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.yearlySchedule = mapped
    }

    internal fun build(): LongTermRetentionPolicyArgs = LongTermRetentionPolicyArgs(
        dailySchedule = dailySchedule,
        monthlySchedule = monthlySchedule,
        retentionPolicyType = retentionPolicyType ?: throw PulumiNullFieldException("retentionPolicyType"),
        weeklySchedule = weeklySchedule,
        yearlySchedule = yearlySchedule,
    )
}
